@@ -1,18 +1,17 @@
 /*
-   SPDX-FileCopyrightText: 2012-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2012-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef KPIMTEXTEDIT_FINDBARBASE_H
-#define KPIMTEXTEDIT_FINDBARBASE_H
+#pragma once
 
-#include "kpimtextedit_export.h"
 #include "kpimtextedit/texteditfindbarbase.h"
-#include <QTextDocument>
+#include "kpimtextedit_export.h"
 
 class QPlainTextEdit;
-namespace KPIMTextEdit {
+namespace KPIMTextEdit
+{
 class PlainTextEditFindBarPrivate;
 /**
  * @brief The PlainTextEditFindBar class
@@ -29,8 +28,8 @@ public:
 protected:
     Q_REQUIRED_RESULT bool viewIsReadOnly() const override;
     Q_REQUIRED_RESULT bool documentIsEmpty() const override;
-    Q_REQUIRED_RESULT bool searchInDocument(const QString &text, QTextDocument::FindFlags searchOptions) override;
-    Q_REQUIRED_RESULT bool searchInDocument(const QRegularExpression &regExp, QTextDocument::FindFlags searchOptions) override;
+    Q_REQUIRED_RESULT bool searchInDocument(const QString &text, TextEditFindBarBase::FindFlags searchOptions) override;
+    Q_REQUIRED_RESULT bool searchInDocument(const QRegularExpression &regExp, TextEditFindBarBase::FindFlags searchOptions) override;
     void autoSearchMoveCursor() override;
 
 public Q_SLOTS:
@@ -41,8 +40,6 @@ private Q_SLOTS:
     void slotReplaceAllText() override;
 
 private:
-    PlainTextEditFindBarPrivate *const d;
+    std::unique_ptr<PlainTextEditFindBarPrivate> const d;
 };
 }
-
-#endif
